import { DocumentNode } from 'graphql';
import Collection from '../models/Collection';
import { performSafeRequestREST, performSafeRequestGraphql } from '../utils';
import EventEmitter from '../EventEmitter';
import { GraphQLErrorBag, PropertyFunction, ResolvingRESTOptions, UrlResolver, HttpMethod, KeyValueUnknown } from '../typings';
import { Observable } from 'apollo-client/util/Observable';
export default abstract class Repository<M = unknown> extends EventEmitter {
    private _exists;
    protected performSafeRequestGraphql: typeof performSafeRequestGraphql;
    protected performSafeRequestREST: typeof performSafeRequestREST;
    loading: boolean;
    lastError: Error | GraphQLErrorBag;
    method: string;
    dataset: Collection<M>;
    queryParams: KeyValueUnknown;
    subscriptions(): unknown[];
    model: M | unknown;
    abstract fetchOneQuery: string | PropertyFunction<string>;
    abstract fetchManyQuery: string | PropertyFunction<string>;
    constructor(array?: Collection<M> | M[]);
    get className(): string;
    get displayClassName(): string;
    get defaultMethod(): "get" | "post";
    exists(): boolean;
    getMethod(opts: ResolvingRESTOptions): string;
    fromArray(array: unknown[], skipEmpty?: boolean): Collection<M>;
    static fromArray<T, R extends Repository>(array: T[], skipEmpty?: boolean): R;
    protected onError(e: Error | GraphQLErrorBag): void;
    query(queryOrUrl: string | UrlResolver | DocumentNode, params?: unknown, collection?: boolean, method?: HttpMethod): Promise<any>;
    processSubscription(observer: Observable<unknown>, doc: DocumentNode): void;
    beforeQuery(): Promise<void>;
    processResponse(collection: any, data: any): Promise<any>;
    afterQuery(): Promise<void>;
    many(params?: any): Promise<Collection<M>>;
    one(id?: unknown): Promise<any>;
    subscribeToMore(params?: any): Promise<void>;
    static one(params?: unknown): any;
}
//# sourceMappingURL=Repository.d.ts.map